# Task

This section contains the API reference for the `distilabel` tasks.

For more information on how the [`Task`][distilabel.steps.tasks.Task] works and see some examples, check the [Tutorial - Task](../../sections/how_to_guides/basic/task/index.md) page.

::: distilabel.steps.tasks.base
    options:
        members:
            - _Task
            - Task
